pub struct DungeonTemplate {
pub id: DungeonTemplateId,
pub title: I18nString,
pub description: I18nString,
pub key_currency_id: CurrencyId,
pub max_difficulty_level: i64,
pub ui_banner_path: String,
pub ui_background_path: String,
pub tips: Vec<DungeonTip>,
pub fight_template_ids: Vec<FightTemplateId>,
pub rewards_by_difficulty: Vec<DungeonRewards>,
pub main_reward: RewardType,
pub chapter_level_unlock: i64,
}Fields
id: DungeonTemplateIdtitle: I18nStringdescription: I18nStringkey_currency_id: CurrencyIdmax_difficulty_level: i64ui_background_path: Stringtips: Vec<DungeonTip>fight_template_ids: Vec<FightTemplateId>rewards_by_difficulty: Vec<DungeonRewards>main_reward: RewardTypechapter_level_unlock: i64Trait Implementations
Sourceimpl Clone for DungeonTemplate
impl Clone for DungeonTemplate
Sourcefn clone(&self) -> DungeonTemplate
fn clone(&self) -> DungeonTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DungeonTemplate
impl Debug for DungeonTemplate
Sourceimpl<'de> Deserialize<'de> for DungeonTemplate
impl<'de> Deserialize<'de> for DungeonTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DungeonTemplate
impl JsonSchema for DungeonTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DungeonTemplate
impl Serialize for DungeonTemplate
Sourceimpl Tsify for DungeonTemplate
impl Tsify for DungeonTemplate
const DECL: &'static str = "export interface DungeonTemplate {\n id: DungeonTemplateId;\n title: I18nString;\n description: I18nString;\n key_currency_id: CurrencyId;\n max_difficulty_level: number;\n ui_banner_path: string;\n ui_background_path: string;\n tips: DungeonTip[];\n fight_template_ids: FightTemplateId[];\n rewards_by_difficulty: DungeonRewards[];\n main_reward: RewardType;\n chapter_level_unlock: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>