pub struct DungeonTip {
pub difficulty_level: u64,
pub tip: I18nString,
}Fields
difficulty_level: u64tip: I18nStringTrait Implementations
Sourceimpl Clone for DungeonTip
impl Clone for DungeonTip
Sourcefn clone(&self) -> DungeonTip
fn clone(&self) -> DungeonTip
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DungeonTip
impl Debug for DungeonTip
Sourceimpl<'de> Deserialize<'de> for DungeonTip
impl<'de> Deserialize<'de> for DungeonTip
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DungeonTip
impl JsonSchema for DungeonTip
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DungeonTip
impl Serialize for DungeonTip
Sourceimpl Tsify for DungeonTip
impl Tsify for DungeonTip
const DECL: &'static str = "export interface DungeonTip {\n difficulty_level: number;\n tip: I18nString;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>