pub struct Dungeons {
pub completed_difficulties: HashMap<DungeonTemplateId, i64>,
}Fields
completed_difficulties: HashMap<DungeonTemplateId, i64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Dungeons
impl<'de> Deserialize<'de> for Dungeons
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Dungeons
impl JsonSchema for Dungeons
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Dungeons
impl Tsify for Dungeons
const DECL: &'static str = "export interface Dungeons {\n completed_difficulties: Record<DungeonTemplateId, number>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Dungeons
impl StructuralPartialEq for Dungeons